## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Run breezy/bazaar integration tests?
#
# breezy dumps core with Python 3.14: Segmentation fault when invoking brz
# whoami 'Your Name <name@example.com>'
# https://bugzilla.redhat.com/show_bug.cgi?id=2366194
%bcond breezy 0

%global _description %{expand:
Dunamai is a Python 3.5+ library and command line tool for producing dynamic,
standards-compliant version strings, derived from tags in your version control
system. This facilitates uniquely identifying nightly or per-commit builds in
continuous integration and releasing new versions of your software simply by
creating a tag.}

Name:           python-dunamai
Version:        1.25.0
Release:        %{autorelease}
Summary:        Dynamic version generation

# SPDX
License:        MIT
URL:            https://pypi.org/pypi/dunamai
Source0:        https://github.com/mtkennerly/dunamai/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch

%description %_description

%package -n python3-dunamai
Summary:        %{summary}
BuildRequires:  python3-devel

BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-xdist)

BuildRequires:  /usr/bin/git
BuildRequires:  /usr/bin/hg
BuildRequires:  /usr/bin/darcs
BuildRequires:  /usr/bin/svn
%if %{with breezy}
BuildRequires:  /usr/bin/bzr
%endif
BuildRequires:  /usr/bin/fossil
BuildRequires:  help2man
# pijul is not in Fedora yet
#BuildRequires:  /usr/bin/pijul

%description -n python3-dunamai %_description

%prep
%autosetup -n dunamai-%{version}

# Comment out to remove /usr/bin/env shebangs
# Can use something similar to correct/remove /usr/bin/python shebangs also
# find . -type f -name "*.py" -exec sed -i '/^#![  ]*\/usr\/bin\/env.*$/ d' {} 2>/dev/null ';'

# see pyproject-rpm-macros documentation for more forms
%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files dunamai

# generate man pages
for binary in "dunamai" "dunamai check" "dunamai from" "dunamai from any" "dunamai from bazaar" "dunamai from darcs" "dunamai from fossil" "dunamai from git" "dunamai from mercurial" "dunamai from pijul" "dunamai from subversion"
do
    echo "Generating man page for ${binary// /-/}"
    PYTHONPATH="$PYTHONPATH:%{buildroot}/%{python3_sitelib}/" PATH="$PATH:%{buildroot}/%{_bindir}/" help2man --no-info --no-discard-stderr --name="${binary}" --version-string="${binary} %{version}" --output="${binary// /-}.1" "${binary}"
    cat "${binary// /-}.1"
    install -t '%{buildroot}%{_mandir}/man1' -p -m 0644 -D "${binary// /-}.1"
done


%check
# set up git
git config --global user.email "you@example.com"
git config --global user.name "Your Name"
%if %{with breezy}
# set up bzr
bzr whoami "Your Name <name@example.com>"
%endif
# set up darcs
export DARCS_EMAIL="Yep something <name@example.com>"

# skip test that requires network
%pytest -n auto -v -k "not test__version__from_git__shallow"

%files -n python3-dunamai -f %{pyproject_files}
%doc README.md CHANGELOG.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/dunamai
%{_mandir}/man1/dunamai*.1*

%changelog
## START: Generated by rpmautospec
* Fri Jul 04 2025 Packit <hello@packit.dev> - 1.25.0-1
- Update to 1.25.0 upstream release
- Resolves: rhbz#2376448

* Thu Jun 19 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.24.1-3
- Disable breezy/bazaar integration tests for now (close RHBZ#2371874)

* Tue Jun 03 2025 Python Maint <python-maint@redhat.com> - 1.24.1-2
- Rebuilt for Python 3.14

* Fri May 09 2025 Packit <hello@packit.dev> - 1.24.1-1
- Update to 1.24.1 upstream release
- Resolves: rhbz#2365333

* Thu May 08 2025 Packit <hello@packit.dev> - 1.24.0-1
- Update to 1.24.0 upstream release
- Resolves: rhbz#2364439

* Fri Mar 21 2025 Packit <hello@packit.dev> - 1.23.1-1
- Update to 1.23.1 upstream release
- Resolves: rhbz#2353990

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.23.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Mon Nov 18 2024 Packit <hello@packit.dev> - 1.23.0-1
- Update to 1.23.0 upstream release
- Resolves: rhbz#2326880

* Wed Aug 07 2024 Packit <hello@packit.dev> - 1.22.0-1
- Update to 1.22.0 upstream release
- Resolves: rhbz#2303339

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.21.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed Jul 03 2024 Packit <hello@packit.dev> - 1.21.2-1
- Update to 1.21.2 upstream release
- Resolves: rhbz#2295462

* Fri Jun 07 2024 Python Maint <python-maint@redhat.com> - 1.21.1-2
- Rebuilt for Python 3.13

* Sat May 04 2024 Packit <hello@packit.dev> - 1.21.1-1
- Update to 1.21.1 upstream release
- Resolves: rhbz#2277902

* Fri Apr 12 2024 Packit <hello@packit.dev> - 1.20.0-1
- Update to 1.20.0 upstream release
- Resolves: rhbz#2274730

* Fri Feb 16 2024 Packit <hello@packit.dev> - 1.19.2-1
- [packit] 1.19.2 upstream release
- Resolves rhbz#2264600

* Wed Feb 07 2024 Packit <hello@packit.dev> - 1.19.1-1
- [packit] 1.19.1 upstream release
- Resolves rhbz#2263185

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.19.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.19.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Oct 04 2023 Packit <hello@packit.dev> - 1.19.0-1
- [packit] 1.19.0 upstream release

* Fri Sep 22 2023 Packit <hello@packit.dev> - 1.18.1-1
- [packit] 1.18.1 upstream release

* Mon Aug 14 2023 Packit <hello@packit.dev> - 1.18.0-1
- [packit] 1.18.0 upstream release

* Mon Aug 14 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.17.0-4
- chore: add packit

* Tue Jul 25 2023 Python Maint <python-maint@redhat.com> - 1.17.0-3
- Rebuilt for Python 3.12

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.17.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jun 09 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.17.0-1
- feat: update to 1.17.0 (fixes rhbz#2208495)

* Mon May 15 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.16.1-1
- feat: update to 1.16.1 (fixes rhbz#2171994)

* Mon May 15 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.16.0-2
- fix: fix man page generation

* Mon May 01 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.16.0-1
- feat: update to 1.16.0 (fixes rbhz#2171994)

* Mon May 01 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.15.0-4
- feat: generate man pages as part of build

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.15.0-2
- Add man pages

* Sun Dec 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.15.0-1
- Update to 1.15.0 (close RHBZ#2140491)

* Sun Dec 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.2-6
- Run tests in parallel

* Sun Dec 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.2-5
- Add missing BR on setuptools

* Sun Dec 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.2-4
- Confirm License is SPDX MIT

* Tue Nov 01 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.13.2-3
- chore: check in sources (fix rhbz#2138899)

* Tue Nov 01 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.13.2-2
- feat: ready for review

* Tue Nov 01 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.13.2-1
- init
## END: Generated by rpmautospec
